==> haskell-nonce-1.0.7-167-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-nonce.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 nonce
version:              1.0.7
visibility:           public
id:                   nonce-1.0.7-E6gQgVJjs4JJurQjJAY2mY
key:                  nonce-1.0.7-E6gQgVJjs4JJurQjJAY2mY
license:              BSD-3-Clause
copyright:            (c) 2014 Prowdsponsor
maintainer:           Prowdsponsor <opensource@prowdsponsor.com>
author:               Felipe Lessa <felipe.lessa@prowdsponsor.com>
homepage:             https://github.com/prowdsponsor/nonce
synopsis:             Generate cryptographic nonces.
description:
    According to the Wikipedia, a nonce is an arbitrary number used
    only once in a cryptographic communication.  This package
    contain helper functions for generating nonces.

    There are many kinds of nonces used in different situations.
    It'\''s not guaranteed that by using the nonces from this package
    you won'\''t have any security issues.  Please make sure that the
    nonces generated via this package are usable on your design.

category:             Cryptography
abi:                  310c3ab641a7e6499b814d41ec0fb0f7
exposed:              True
exposed-modules:      Crypto.Nonce
import-dirs:          /usr/lib/ghc-8.10.4/site-local/nonce-1.0.7
library-dirs:         /usr/lib/ghc-8.10.4/site-local/nonce-1.0.7
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.4/nonce-1.0.7
hs-libraries:         HSnonce-1.0.7-E6gQgVJjs4JJurQjJAY2mY
depends:
    base-4.14.1.0 base64-bytestring-1.2.0.1-ClIBjZKg2SyKsdFOYXYUB8
    bytestring-0.10.12.0 entropy-0.4.1.6-6Z0sejCw1fy7sJ1AU1oQ6y
    text-1.2.4.1 transformers-0.5.6.2
    unliftio-0.2.14-9ZkpadKoElZKW8c2tTXoSo
    unliftio-core-0.2.0.1-9GVcmaajsglG88oErAZOTV

haddock-interfaces:   /usr/share/doc/haskell-nonce/html/nonce.haddock
haddock-html:         /usr/share/doc/haskell-nonce/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-nonce-1.0.7-168-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-nonce.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 nonce
version:              1.0.7
visibility:           public
id:                   nonce-1.0.7-GqdJ3JRKQV6HJM8dcij1SD
key:                  nonce-1.0.7-GqdJ3JRKQV6HJM8dcij1SD
license:              BSD-3-Clause
copyright:            (c) 2014 Prowdsponsor
maintainer:           Prowdsponsor <opensource@prowdsponsor.com>
author:               Felipe Lessa <felipe.lessa@prowdsponsor.com>
homepage:             https://github.com/prowdsponsor/nonce
synopsis:             Generate cryptographic nonces.
description:
    According to the Wikipedia, a nonce is an arbitrary number used
    only once in a cryptographic communication.  This package
    contain helper functions for generating nonces.

    There are many kinds of nonces used in different situations.
    It'\''s not guaranteed that by using the nonces from this package
    you won'\''t have any security issues.  Please make sure that the
    nonces generated via this package are usable on your design.

category:             Cryptography
abi:                  cbd4a1b24f692c750864cbe111a33ce6
exposed:              True
exposed-modules:      Crypto.Nonce
import-dirs:          /usr/lib/ghc-8.10.4/site-local/nonce-1.0.7
library-dirs:         /usr/lib/ghc-8.10.4/site-local/nonce-1.0.7
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.4/nonce-1.0.7
hs-libraries:         HSnonce-1.0.7-GqdJ3JRKQV6HJM8dcij1SD
depends:
    base-4.14.1.0 base64-bytestring-1.2.0.1-nm7ysOr2is2xIk66IzcwV
    bytestring-0.10.12.0 entropy-0.4.1.6-6Z0sejCw1fy7sJ1AU1oQ6y
    text-1.2.4.1 transformers-0.5.6.2
    unliftio-0.2.14-3gplOfyXp4OJMRNrlfJp3E
    unliftio-core-0.2.0.1-9GVcmaajsglG88oErAZOTV

haddock-interfaces:   /usr/share/doc/haskell-nonce/html/nonce.haddock
haddock-html:         /usr/share/doc/haskell-nonce/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
